Writable

Trait Writable 

pub trait Writable: RegisterSpec {
    type Safety;

    const ZERO_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO;
    const ONE_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO;
}
Trait implemented by writeable registers.

This enables the write, write_with_zero and reset methods.

Registers marked with Readable can be also be modify’ed.

Provided Associated Constants

const ZERO_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO

Specifies the register bits that are not changed if you pass 1 and are changed if you pass 0

const ONE_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO

Specifies the register bits that are not changed if you pass 0 and are changed if you pass 1

Required Associated Types

type Safety

Is it safe to write any bits to register

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Writable for ControlSpec

write(|w| ..) method takes control::W writer structure

Source

impl Writable for DataSpec

write(|w| ..) method takes data::W writer structure