pub trait Writable: RegisterSpec {
type Safety;
const ZERO_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO;
const ONE_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO;
}Expand description
Trait implemented by writeable registers.
This enables the write, write_with_zero and reset methods.
Registers marked with Readable can be also be modify’ed.
Provided Associated Constants
Sourceconst ZERO_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO
const ZERO_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO
Specifies the register bits that are not changed if you pass 1 and are changed if you pass 0
Sourceconst ONE_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO
const ONE_TO_MODIFY_FIELDS_BITMAP: Self::Ux = <Self::Ux>::ZERO
Specifies the register bits that are not changed if you pass 0 and are changed if you pass 1
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.